@@ -1,13 +1,14 @@
 use strict;
 use warnings;
-use Graphics::Raylib::Color;
 package Graphics::Raylib::Shape;
 
 # ABSTRACT: Collection of drawable shapes
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use List::Util qw(min max);
 use Graphics::Raylib::XS qw(:all);
+use Graphics::Raylib::Color;
+use Graphics::Raylib::Util;
 
 =pod
 
@@ -20,22 +21,22 @@ Graphics::Raylib::Shape - Collection of drawable shapes
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
-    use Graphics::Raylib::Pixel;
-    use Graphics::Raylib::Circle;
-    use Graphics::Raylib::Rectangle;
-    use Graphics::Raylib::Triangle;
-    use Graphics::Raylib::Poly;
+    use Graphics::Raylib::Shape::Pixel;
+    use Graphics::Raylib::Shape::Circle;
+    use Graphics::Raylib::Shape::Rectangle;
+    use Graphics::Raylib::Shape::Triangle;
+    use Graphics::Raylib::Shape::Bitmap;
 
     # example
 
     my $rect = Graphics::Raylib::Rectangle(
         pos   => [0,0],
         size  => [10,10],
-        color => Graphics::Raylib::Rectange::MAROON,
+        color => Graphics::Raylib::Color::MAROON,
     )->draw;
 
 =head1 DESCRIPTION
@@ -211,20 +212,25 @@ sub triangle {
     sub color :lvalue { $_[0]->{color}  }
 }
 
-=item bitmap( matrix => $AoA, width => $screen_width, height => $screen_height, color => $color )
+=item bitmap( matrix => $AoA, color => $color, [ width => $screen_width, height => $screen_height, transpose => 0, $roatate => 0 ])
 
-Creates a texture out of a matrix for printing. C<$AoA> is an array of arrays ref. C<$screen_width> and C<$screenheight> are the size of the area on which the Matrix should be drawn. It defaults to the screen size.
+Creates a texture out of a matrix for printing. C<$AoA> is an array of arrays ref. C<$screen_width> and C<$screenheight> are the size of the area on which the Matrix should be drawn. It's optional defaults to the screen size.
 
 If C<$color> is a C<Graphics::Raylib::Color>, it will be used to color all positive $AoA elements. The space occupied by negative and zero elements stays at background color.
 
-if $color is a code reference, It will be evaluated for each matrix element, with the element's value as argument. The return type of the code reference will be used for the color. Return C<undef>, for omitting the element.
+if C<$color> is a code reference, It will be evaluated for each matrix element, with the element's value as argument. The return type of the code reference will be used for the color. Return C<undef>, for omitting the element.
+
+C<< transpose => >> determines whether the image should be drawn transposed ( x,y flipped ). It's more effecient than transposing in a separate step.
+
+C<< rotate => >> sets an angle (in degrees) for rotation. Rotation origin is the center of the bitmap.
 
 Example:
 
+    use Graphics::Raylib '+family';
     use PDL;
     use PDL::Matrix;
 
-    my $pdl = mpdl [
+    my $pdl = mpdl[
                      [0, 1, 1, 1, 0],
                      [1, 0, 0, 0, 0],
                      [0, 1, 1, 1 ,0],
@@ -233,40 +239,45 @@ Example:
                    ];
 
     my $g = Graphics::Raylib->window(240, 240);
+    $g->fps(60);
 
-    $g->fps(10);
+    my $bitmap = Graphics::Raylib::Shape->bitmap(matrix => unpdl($pdl), color => YELLOW, transposed => 1);
 
-    my $i = 0;
-    while (!$g->exiting)
-    {
-
-        my $bitmap = Graphics::Raylib::Shape->bitmap(
-            matrix => unpdl($gen),
-            color  => Graphics::Raylib::Color::YELLOW;
-        );
+    while (!$g->exiting) {
+        $bitmap->matrix = unpdl($pdl);
+        $bitmap->rotation -= 1;
 
         Graphics::Raylib::draw {
-            $g->clear(Graphics::Raylib::Color::BLACK);
-
+            $g->clear(BLACK);
             $bitmap->draw;
         };
 
 
         # now do some operations on $pdl, to get next iteration
-
     }
 
-See the game of life example at L<Graphics::Raylib> (or C<t/10-game-of-life.t>) for a more complete example.
+
+See the game of life example at L<Graphics::Raylib> (or C<t/30-game-of-life.t>) for a more complete example.
 
 =cut
 
 {
     package Graphics::Raylib::Shape::Bitmap;
+    use Graphics::Raylib::XS;
     sub draw {
         my $self = shift;
         Graphics::Raylib::Shape::_bitmap($self) if $self->{rebitmap};
 
-        Graphics::Raylib::XS::DrawTexture($self->{texture}, 0, 0, Graphics::Raylib::Color::WHITE);
+        Graphics::Raylib::XS::DrawTexturePro(
+            $self->{texture},
+            Graphics::Raylib::Util::rectangle(x => 0, y => 0, width => $self->{width}, height => $self->{height}),
+
+            Graphics::Raylib::Util::rectangle(x => ($self->{x} + Graphics::Raylib::XS::GetScreenWidth())/2, y => ($self->{y} + Graphics::Raylib::XS::GetScreenHeight()) / 2, width => $self->{width}*$self->{scale}, height => $self->{height}*$self->{scale}),
+
+            Graphics::Raylib::Util::vector($self->{width}*$self->{scale}/2, $self->{width}*$self->{scale}/2),
+
+            $self->{rotation}, $self->{tint});
+        #Graphics::Raylib::XS::DrawTexture($self->{texture}, 0,0, $self->{tint});
     }
     sub matrix :lvalue {
         my $self = shift;
@@ -274,6 +285,11 @@ See the game of life example at L<Graphics::Raylib> (or C<t/10-game-of-life.t>)
         $self->{rebitmap} = 1;
         $self->{matrix};
     }
+    sub rotation :lvalue {
+        my $self = shift;
+
+        $self->{rotation};
+    }
     sub color :lvalue { $_[0]->{color}  }
     sub DESTROY {
           my $self = shift;
@@ -285,22 +301,20 @@ sub _bitmap {
     my $self = shift;
 
     unless (defined $self->{height} && defined $self->{width}) {
-        my $maxheight = scalar @{$self->{matrix}};
-        my $maxwidth  = max map { scalar @$_ } @{$self->{matrix}};
-
-        # cell sizes
-        $self->{width}  = GetScreenWidth()  / ($maxwidth-1);
-        $self->{height} = GetScreenHeight() / ($maxheight-1);
+        $self->{width}  = GetScreenWidth();
+        $self->{height} = GetScreenHeight();
     }
 
     my $color = $self->{color} // Graphics::Raylib::Color::GOLD;
     $self->{color} = ref($color) eq 'CODE' ? $color : sub { shift > 0 ? $color : undef };
 
-    unless ($self->{uninitialized}) {
-        $self->{image} = LoadImageFromAV($self->{matrix}, $self->{color}, $self->{width}, $self->{height});
-    } else {
-        $self->{image} = LoadImageFromAV_uninitialized_mem($self->{matrix}, $self->{color}, $self->{width}, $self->{height});
-    }
+    my $func = $self->{transposed} && $self->{uninitialized} ? \&LoadImageFromAV_transposed_uninitialized_mem
+             : $self->{transposed}                           ? \&LoadImageFromAV_transposed
+             :                        $self->{uninitialized} ? \&LoadImageFromAV_uninitialized_mem
+             :                                                 \&LoadImageFromAV;
+
+            $self->{image} = $func->($self->{matrix}, $self->{color}, $self->{width}, $self->{height});
+
     if (defined $self->{texture}) {
         UpdateTextureFromImage($self->{texture}, $self->{image});
     } else {
@@ -313,9 +327,12 @@ sub _bitmap {
 
 sub bitmap {
     my $class = shift;
-    my $self = { uninitialized => 0, @_ };
+    my $self = {
+        uninitialized => 0, deferred => 0, rotation => 0, scale => 1, x => 0, y => 0,
+        tint => Graphics::Raylib::Color::WHITE, @_
+    };
 
-    _bitmap($self);
+    $self->{deferred} and $self->{rebitmap} = 1 or _bitmap($self);
 
     bless $self, 'Graphics::Raylib::Shape::Bitmap';
     return $self;
